==> kdebase-3.0.1.tar.bz2: kdebase-3.0.1/kicker/buttons/kbutton.cpp <==
/*****************************************************************

Copyright (c) 1996-2001 the kicker authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#include <qtooltip.h>

#include <klocale.h>
#include <kapplication.h>
#include <kdebug.h>

#include "kicker.h"
#include "k_mnu.h"

#include "kbutton.h"
#include "kbutton.moc"

KButton::KButton( QWidget* parent )
    : PanelPopupButton( parent, "KButton" )
{
    QToolTip::add(this, i18n("Start Application"));
    setTitle(i18n("Start Application"));

    setPopup( Kicker::kicker()->KMenu() );
    setIcon("kmenu");
}

void KButton::properties()
{
    KApplication::startServiceByDesktopName("kmenuedit", QStringList(),
                                            0, 0, 0, "", true);
}

void KButton::initPopup()
{
//    kdDebug(1210) << "KButton::initPopup()" << endl;

    // this hack is required to ensure the correct popup position
    // when the size of the recent application part of the menu changes
    // please don't remove this _again_
    Kicker::kicker()->KMenu()->initialize();
}

==> kdebase-3.1.4.tar.bz2: kdebase-3.1.4/kicker/buttons/kbutton.cpp <==
/*****************************************************************

Copyright (c) 1996-2001 the kicker authors. See file AUTHORS.

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
AUTHORS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

******************************************************************/

#include <qtooltip.h>

#include <klocale.h>
#include <kapplication.h>
#include <kdebug.h>

#include "kicker.h"
#include "k_mnu.h"

#include "kbutton.h"
#include "kbutton.moc"

KButton::KButton( QWidget* parent )
    : PanelPopupButton( parent, "KButton" )
{
    QToolTip::add(this, i18n("Start Applications"));
    setTitle(i18n("Start Applications"));

    setPopup( Kicker::kicker()->KMenu() );
    setIcon("kmenu");
}

void KButton::properties()
{
    KApplication::startServiceByDesktopName("kmenuedit", QStringList(),
                                            0, 0, 0, "", true);
}

void KButton::initPopup()
{
//    kdDebug(1210) << "KButton::initPopup()" << endl;

    // this hack is required to ensure the correct popup position
    // when the size of the recent application part of the menu changes
    // please don't remove this _again_
    Kicker::kicker()->KMenu()->initialize();
}
